% neur_loadmorph(nc,compmaxsize)
% 
% Assigns parameters for the compartments
%
% inputs: nc : structure containing morphology data from trace file
%         
%         compmaxsize : maximum compartment size in (um)
%
% outputs: md : structure containing compartment parameters
%
%          md.count.N : number of dendritic branches in the cell
%          md.count.L : number of compartments total in the cell
%
%          (not currently used)
%          md.interp.radii : radii of each compartment
%          md.interp.size  : length of each compartment

function md = neur_loadmorph2(nc,compmaxsize,crat)

md.count.N = length(nc.celldata);

md.parents = zeros(md.count.N,1);
md.par = [];

p = 1;
paryes = 0;

% traverses through all of the branches to md.interpolate radii

for j = 1:md.count.N         
    
    % finds physical length of the current branch
    
    md.grid.segL(j) = nc.lendata{j}(nc.segsize(j))*1e-4;   
    
    % md.interpolates radii for the current segment
    
    % number of compartments needed
    
    md.grid.comps(j) = ceil(md.grid.segL(j)/(compmaxsize));       
    
    % compartment length calculated
    
    md.grid.hstep(j) = md.grid.segL(j)/md.grid.comps(j);            
    
    md.interp.radii{j} = 1e-4*interp1(nc.lendata{j},...
                        (nc.celldata{j}(1:nc.segsize(j),4))',...
                         0:md.grid.hstep(j):md.grid.segL(j))/2;
                         
    md.interp.size(j) = length(md.interp.radii{j});
    
    % grid and coarsened mesh
    
    % regular spatial mesh 
    
    md.grid.x{j} = linspace(0,md.grid.segL(j),md.interp.size(j));
    
    % coarsened spatial mesh
    
    md.grid.crat = crat;
    md.grid.Cnumleft(j) = mod(md.interp.size(j)-1,md.grid.crat);
    md.grid.Cnumreg(j) = floor((md.interp.size(j)-1)/md.grid.crat);
    
    md.grid.Cx{j} = 0:md.grid.crat*md.grid.hstep(j):md.grid.segL(j);
    
    if md.grid.Cnumleft(j) > 0
        md.grid.Cx{j} = [md.grid.Cx{j}(1:end) md.grid.segL(j)];    
    end
    
    % regular and coarsened 'middle' mesh
    
    md.grid.xmid{j} = md.grid.x{j}(1:end-1)+diff(md.grid.x{j})/2;
    md.grid.Cxmid{j} = md.grid.Cx{j}(1:end-1)+diff(md.grid.Cx{j})/2;
                             
    % find parents

    if size(nc.treedata{j},2) > 0
        md.par(p) = j;
        p = p + 1;
        paryes = 1;
        
        for k = 1:length(nc.treedata{j})
            md.parents(nc.treedata{j}(k)) = j;
        end
    end    
    
    % get those leaves

    leaves = ones(1,md.count.N);
    leaves(md.par) = 0;
    md.leaf = find(leaves == 1);

    clear leaves

    % find largest radius
    
    md.maxrad(j) = max(nc.celldata{j}(1:nc.segsize(j),4));
    
end

[md.interp.rsize, md.interp.gsize] = neur_morphresize(nc,md);

md.count.L = sum(md.interp.size)-size(md.interp.size,2)+1;

if paryes 
    md.count.P = size(md.par,2);
else
    md.count.P = 0;
end

% find the largest radius

md.maxrad = max(md.maxrad);

function [rsize,gsize] = neur_morphresize(nc,md)

for ii = 1:md.count.N

    % make tempsize array (adjust for triple-click)
    
    rsize(ii) = md.interp.size(ii)-1;
    gsize(ii) = rsize(ii);
    fr = nc.roots(find(nc.roots == ii));
    rsize(fr) = rsize(fr) + 1;
    
end